(News)=
## News

<!-- marker: after prelude -->

### `rapids-singlecell` brings scanpy to the GPU! {small}`2024-03-18`

{doc}`rapids-singlecell <rapids_singlecell:index>` by Severin Dicks provides a scanpy-like API with accelerated operations implemented on GPU.

### Scanpy hits 100 contributors! {small}`2022-03-31`

[100 people have contributed to Scanpy's source code!](https://github.com/scverse/scanpy/graphs/contributors)

Of course, contributions to the project are not limited to direct modification of the source code.
Many others have improved the project by building on top of it, participating in development discussions, helping others with usage, or by showing off what it's helped them accomplish.

Thanks to all our contributors for making this project possible!

### New community channels {small}`2022-03-31`

We've moved our forums and have a new publicly available chat!

* Our discourse forum has migrated to a joint scverse forum ([discourse.scverse.org](https://discourse.scverse.org)).
* Our private developer Slack has been replaced by a public Zulip chat ([scverse.zulipchat.com](https://scverse.zulipchat.com)).

### Toolkit for spatial (squidpy) and multimodal (muon) published {small}`2022-02-01`

Two large toolkits extending our ecosystem to new modalities have had their manuscripts published!

* [Muon](https://muon.readthedocs.io/), a framework for multimodal has been published in [Genome Biology](https://genomebiology.biomedcentral.com/articles/10.1186/s13059-021-02577-8).
* [Squidpy](https://squidpy.readthedocs.io/) a toolkit for working with spatial single cell data has been published in [Nature Methods](https://www.nature.com/articles/s41592-021-01358-2).

<!-- marker: before old news -->

### scVelo on the cover of Nature Biotechnology {small}`2020-12-01`

Scanpy's counterpart for RNA velocity, [scVelo](https://scvelo.org/), made it on the cover of [Nature Biotechnology](https://www.nature.com/nbt/volumes/38/issues/12) \[[tweet](https://twitter.com/NatureBiotech/status/1334647540030070792)\].

### Scanpy selected among 20 papers for 20 years of Genome Biology {small}`2020-08-01`

[Genome Biology: Celebrating 20 Years of Genome Biology](https://genomebiology.biomedcentral.com/20years) selected the initial Scanpy paper for the year 2018 among 20 papers for 20 years \[[tweet](https://twitter.com/falexwolf/status/1295748952504045572)\].

### COVID-19 datasets distributed as `h5ad` {small}`2020-04-01`

In a joint initiative, the Wellcome Sanger Institute, the Human Cell Atlas, and the CZI distribute datasets related to COVID-19 via anndata's `h5ad` files: [covid19cellatlas.org](https://www.covid19cellatlas.org/). It wasn't anticipated that the [initial idea](https://falexwolf.de/blog/2017-12-23-anndata-indexing-views-HDF5-backing/) of sharing and backing an on-disk representation of `AnnData` would become so widely adopted. Curious? Read up more on the [format](https://anndata.readthedocs.io/en/latest/fileformat-prose.html).

### Scanpy featured in Nature Biotechnoloogy {small}`2020-02-01`

[Single-cell RNA-seq analysis software providers scramble to offer solutions](https://www.nature.com/articles/s41587-020-0449-8) mentions Scanpy along with Seurat as the two major open source software packages for single-cell analysis \[[pdf](https://rdcu.be/b2M5l)\].

### Scanpy has been selected an "Essential open source software for science" by CZI {small}`2019-11-14`

Scanpy has been selected an [essential open source software for science] by
CZI among [32 projects], along with giants such as Scipy, Numpy, Pandas,
Matplotlib, scikit-learn, scikit-image/plotly, pip, jupyterhub/binder,
Bioconda, Seurat, Bioconductor, and others.

### Nature Biotechnology: A comparison of single-cell trajectory inference methods {small}`2019-04-01`

[Nature Biotechnology](https://www.nature.com/articles/s41587-019-0071-9) reviews more than 70 TI tools and ranks PAGA as the best graph-based trajectory inference method, and overall, among the top 3.

### Science “Breakthrough of the Year 2018” {small}`2018-12-01`

The Science “Breakthrough of the Year 2018”, [Development cell by cell](https://vis.sciencemag.org/breakthrough2018/finalists/#cell-development), mentions the first application of PAGA {cite:p}`Plass2018` among 5 papers.

[32 projects]: https://chanzuckerberg.com/eoss/proposals/
[essential open source software for science]: https://chanzuckerberg.com/newsroom/chan-zuckerberg-initiative-awards-5-million-for-open-source-software-projects-essential-to-science/
